@@ -60,8 +60,6 @@ def create(name, *args, **kwargs):
         ffmpeg_args, "output", {"t": nb_samples / rate}, file_index=0
     )
 
-    print(ffmpeg_args)
-
     stdout = ffmpeg.run_sync(ffmpeg_args)
     return np.frombuffer(stdout, dtype=dtype).reshape(-1, nch)
 
@@ -76,19 +74,20 @@ def read(url, stream_id=0, **options):
     :param \\**options: other keyword options (see :doc:`options`)
     :type \\**options: dict, optional
     :return: sample rate in samples/second and audio data matrix (timexchannel)
-    :rtype: tuple(`float`, `numpy.ndarray`)
+    :rtype: tuple(`float`, :py:class:`numpy.ndarray`)
+
+    .. note:: Even if :code:`start_time` option is set, all the prior samples will be read. 
+        The retrieved data will be truncated before returning it to the caller.
+        This is to ensure the timing accuracy. As such, do not use this function
+        to perform block-wise processing. Instead use the streaming solution,
+        see :py:func:`open`.
 
-    .. note:: even if `start_time` option is set, prior samples are read, and
-    the retrieved data matrix is truncated before returning it to the caller.
-    This is to ensure the timing accuracy. As such, do not use this function
-    to perform block-wise processing. Instead use the streaming solution,
-    see :py:func:`open`.
 
     """
 
     args = configure.input_timing({}, url, astream_id=stream_id, **options)
 
-    i0, i1 = configure.get_audio_range(args, stream_id)
+    i0, i1 = configure.get_audio_range(args, 0, stream_id)
     if i0 > 0:
         # if start time is set, remove to read all samples from the beginning
         del args["inputs"][0][1]["ss"]
@@ -136,4 +135,4 @@ def write(url, rate, data, **options):
         **options,
     )
 
-    ffmpeg.run_sync(args, input=data.tobytes())
+    ffmpeg.run_sync(args, input=np.asarray(data).tobytes())
